
/* Caricamento dei dati */

GET DATA 
  /TYPE=XLS 
  /FILE='C:\Documents and Settings\Teo Muccigrosso\Documenti\DTE\Bando_ProvinciaRM_corso_SPSS\2013\RDD_30.01.12.xls' 
  /SHEET=name 'ridotto' 
  /CELLRANGE=full 
  /READNAMES=on 
  /ASSUMEDSTRWIDTH=32767. 
EXECUTE. 
DATASET NAME InsiemeDati1 WINDOW=FRONT.


/* Seleziona casi: anzianit delle imprese pari a 7 anni */ 

USE ALL. 
COMPUTE filter_$=(anni_int=7). 
VARIABLE LABELS filter_$ 'anni_int=7 (FILTER)'. 
VALUE LABELS filter_$ 0 'Not Selected' 1 'Selected'. 
FORMATS filter_$ (f1.0). 
FILTER BY filter_$. 
EXECUTE.


* Grafico per una selezione specifica di dati.

* Aggiungere:
* linea verticale in punt_std=0
* titolo grafico: Distribuzione delle imprese per punteggio bando e probabilit di arrivare al settimo anno di vita
* etichette assi 

* Generatore di grafici. 
GGRAPH 
  /GRAPHDATASET NAME="graphdataset" VARIABLES=punt_std Surv_funct MISSING=LISTWISE REPORTMISSING=NO 
  /GRAPHSPEC SOURCE=INLINE. 
BEGIN GPL 
  SOURCE: s=userSource(id("graphdataset")) 
  DATA: punt_std=col(source(s), name("punt_std")) 
  DATA: Surv_funct=col(source(s), name("Surv_funct")) 
  GUIDE: axis(dim(1), label("Punteggio standardizzato (punt_std)")) 
  GUIDE: axis(dim(2), label("Probabilit di sopravvivenza (Surv_funct)")) 
  GUIDE: text.title(label("Distribuzione delle imprese per punteggio bando e probabilit di arrivare al settimo anno di vita")) 
  ELEMENT: point(position(punt_std*Surv_funct)) 
END GPL.


* Togliere il filtro sui dati

FILTER OFF. 
USE ALL. 
EXECUTE.


* Creazione della variabile di interazione

COMPUTE interaz=treat*punt_std. 
EXECUTE.


/* Applicazione del Regression Discontinuity Design (RDD) mediante la stima di un modello lineare generalizzato

UNIANOVA Surv_funct WITH treat interaz 
  /METHOD=SSTYPE(3) 
  /INTERCEPT=INCLUDE 
  /PRINT=DESCRIPTIVE PARAMETER 
  /CRITERIA=ALPHA(.05) 
  /DESIGN=treat interaz.


* Stima di due regressioni separate (per treat=0 e treat=1)
* La differenza delle costanti ci restituisce un valore prossimo al coefficiente della variabile treat
* stimato nel modello generalizzato (jump: effetto della politica) 

SORT CASES  BY treat. 
SPLIT FILE SEPARATE BY treat.

REGRESSION 
  /MISSING LISTWISE 
  /STATISTICS COEFF OUTS R ANOVA  
  /CRITERIA=PIN(.05) POUT(.10) 
  /NOORIGIN 
  /DEPENDENT Surv_funct 
  /METHOD=ENTER punt_std.


